Package: microbiomeDataSets
Title: Experiment Hub based microbiome datasets
Version: 1.20.0
Authors@R: 
    c(
      person("Leo", "Lahti", role = c("cre", "aut"),
             comment = c(ORCID = "0000-0001-5537-637X"),
             email = "leo.lahti@iki.fi"),    
      person(given = "Felix G.M.", family = "Ernst", role = c("aut"),
             email = "felix.gm.ernst@outlook.com",      
             comment = c(ORCID = "0000-0001-5064-0928")),
      person(given = "Sudarshan", "Shetty", role = c("aut"),
             email = "sudarshanshetty9@gmail.com",
             comment = c(ORCID = "0000-0001-7280-9915")),
      person(given = "Chouaib", family = "Benchraka", role = c("ctb"),
             email = "chouaib.benchraka@utu.fi",
             comment = c(ORCID = "0000-0002-1167-7848")),
      person(given = "Yagmur", family = "Simsek", role = c("ctb"))	     
	     )
Description: 
    microbiomeDataSets is a collection of microbiome datasets loaded from 
    Bioconductor'S ExperimentHub infrastructure. The datasets serve as reference
    for workflows and vignettes published adjacent to the microbiome analysis 
    tools on Bioconductor. Additional datasets can be added overtime and 
    additions from authors are welcome.
License: CC0
Encoding: UTF-8
biocViews: ExperimentHub, ExperimentData, MicrobiomeData,
        SequencingData
Depends: R (>= 4.1), SummarizedExperiment, TreeSummarizedExperiment,
        MultiAssayExperiment
Imports: methods, utils, BiocGenerics, ExperimentHub, Biostrings, ape
Suggests: knitr, rmarkdown, BiocStyle, SingleCellExperiment, testthat
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/microbiomeDataSets
git_branch: RELEASE_3_23
git_last_commit: f7f9739
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
NeedsCompilation: no
Packaged: 2026-05-05 15:31:58 UTC; biocbuild
Author: Leo Lahti [cre, aut] (ORCID: <https://orcid.org/0000-0001-5537-637X>),
  Felix G.M. Ernst [aut] (ORCID: <https://orcid.org/0000-0001-5064-0928>),
  Sudarshan Shetty [aut] (ORCID: <https://orcid.org/0000-0001-7280-9915>),
  Chouaib Benchraka [ctb] (ORCID:
    <https://orcid.org/0000-0002-1167-7848>),
  Yagmur Simsek [ctb]
Maintainer: Leo Lahti <leo.lahti@iki.fi>
