#' Microbiome data sets 
#' 
#' \code{microbiomeDataSets} is a collation of data from microbiome and 
#' associated studies, which are publicaly available. 
#' 
#' The data is made available through the ExperimentHub resources of the
#' Bioconductor project. It is loaded as \code{TreeSummarizedExperiment} 
#' object or a \code{MultiAssayExperiment} objects.
#' 
#' @name microbiomeDataSets-package
NULL

#' @importFrom BiocGenerics updateObject
#' @importFrom methods as
NULL