---
title: "microbiomeDataSets"
date: "`r Sys.Date()`"
package: microbiomeDataSets
output: 
    BiocStyle::html_document:
        fig_height: 7
        fig_width: 10
        toc: yes
        toc_depth: 2
        number_sections: true
vignette: >
    %\VignetteIndexEntry{microbiomeDataSets}
    %\VignetteEngine{knitr::rmarkdown}
    %\VignetteEncoding{UTF-8}
bibliography: references.bib  
---

```{r, include = FALSE}
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)
```

```{r setup, message=FALSE}
library(microbiomeDataSets)
```

# Microbiome example data sets

The data sets are primarily named by the first author of the
associated publication, together with a descriptive suffix. Aliases
are provided for some of the data sets.

A table of the available data sets is available through the `availableDataSets`
function.

```{r}
availableDataSets()
```

All data are downloaded from ExperimentHub and cached for local
re-use. Check the [man pages of each
function](https://microbiome.github.io/microbiomeDataSets/reference/index.html)
for a detailed documentation of the data contents and original source.

The microbiome data is usually loaded as a
`r Biocpkg("TreeSummarizedExperiment")`. If other associated data tables
(metabolomic, biomarker..) are provided, the integrated data
collection is provided as `r Biocpkg("MultiAssayExperiment")`.

For more information on how to use these objects, please refer to the
vignettes of those packages.


```{r}
#rebook::prettySessionInfo()
sessionInfo()
```


